==> ecs-1.60.0-sources.jar: software/amazon/awscdk/services/ecs/ContainerImage.java <==
package software.amazon.awscdk.services.ecs;

/**
 * Constructs for types of container images.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:32.998Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ecs.$Module.class, fqn = "@aws-cdk/aws-ecs.ContainerImage")
public abstract class ContainerImage extends software.amazon.jsii.JsiiObject {

    protected ContainerImage(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected ContainerImage(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    protected ContainerImage() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * Reference an image that's constructed directly from sources on disk.
     * <p>
     * If you already have a <code>DockerImageAsset</code> instance, you can use the
     * <code>ContainerImage.fromDockerImageAsset</code> method instead.
     * <p>
     * @param directory The directory containing the Dockerfile. This parameter is required.
     * @param props
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.AssetImage fromAsset(final @org.jetbrains.annotations.NotNull java.lang.String directory, final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ecs.AssetImageProps props) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ecs.ContainerImage.class, "fromAsset", software.amazon.awscdk.services.ecs.AssetImage.class, new Object[] { java.util.Objects.requireNonNull(directory, "directory is required"), props });
    }

    /**
     * Reference an image that's constructed directly from sources on disk.
     * <p>
     * If you already have a <code>DockerImageAsset</code> instance, you can use the
     * <code>ContainerImage.fromDockerImageAsset</code> method instead.
     * <p>
     * @param directory The directory containing the Dockerfile. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.AssetImage fromAsset(final @org.jetbrains.annotations.NotNull java.lang.String directory) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ecs.ContainerImage.class, "fromAsset", software.amazon.awscdk.services.ecs.AssetImage.class, new Object[] { java.util.Objects.requireNonNull(directory, "directory is required") });
    }

    /**
     * Use an existing `DockerImageAsset` for this container image.
     * <p>
     * @param asset The `DockerImageAsset` to use for this container definition. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.ContainerImage fromDockerImageAsset(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecr.assets.DockerImageAsset asset) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ecs.ContainerImage.class, "fromDockerImageAsset", software.amazon.awscdk.services.ecs.ContainerImage.class, new Object[] { java.util.Objects.requireNonNull(asset, "asset is required") });
    }

    /**
     * Reference an image in an ECR repository.
     * <p>
     * @param repository This parameter is required.
     * @param tag
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.EcrImage fromEcrRepository(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecr.IRepository repository, final @org.jetbrains.annotations.Nullable java.lang.String tag) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ecs.ContainerImage.class, "fromEcrRepository", software.amazon.awscdk.services.ecs.EcrImage.class, new Object[] { java.util.Objects.requireNonNull(repository, "repository is required"), tag });
    }

    /**
     * Reference an image in an ECR repository.
     * <p>
     * @param repository This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.EcrImage fromEcrRepository(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecr.IRepository repository) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ecs.ContainerImage.class, "fromEcrRepository", software.amazon.awscdk.services.ecs.EcrImage.class, new Object[] { java.util.Objects.requireNonNull(repository, "repository is required") });
    }

    /**
     * Reference an image on DockerHub or another online registry.
     * <p>
     * @param name This parameter is required.
     * @param props
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.RepositoryImage fromRegistry(final @org.jetbrains.annotations.NotNull java.lang.String name, final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ecs.RepositoryImageProps props) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ecs.ContainerImage.class, "fromRegistry", software.amazon.awscdk.services.ecs.RepositoryImage.class, new Object[] { java.util.Objects.requireNonNull(name, "name is required"), props });
    }

    /**
     * Reference an image on DockerHub or another online registry.
     * <p>
     * @param name This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.RepositoryImage fromRegistry(final @org.jetbrains.annotations.NotNull java.lang.String name) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ecs.ContainerImage.class, "fromRegistry", software.amazon.awscdk.services.ecs.RepositoryImage.class, new Object[] { java.util.Objects.requireNonNull(name, "name is required") });
    }

    /**
     * Called when the image is used by a ContainerDefinition.
     * <p>
     * @param scope This parameter is required.
     * @param containerDefinition This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public abstract @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.ContainerImageConfig bind(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.ContainerDefinition containerDefinition);

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.awscdk.services.ecs.ContainerImage {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * Called when the image is used by a ContainerDefinition.
         * <p>
         * @param scope This parameter is required.
         * @param containerDefinition This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.ContainerImageConfig bind(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.ContainerDefinition containerDefinition) {
            return this.jsiiCall("bind", software.amazon.awscdk.services.ecs.ContainerImageConfig.class, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(containerDefinition, "containerDefinition is required") });
        }
    }
}

==> ecs-1.100.0-sources.jar: software/amazon/awscdk/services/ecs/ContainerImage.java <==
package software.amazon.awscdk.services.ecs;

/**
 * Constructs for types of container images.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.28.0 (build 1801f4f)", date = "2021-04-20T16:34:41.793Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ecs.$Module.class, fqn = "@aws-cdk/aws-ecs.ContainerImage")
public abstract class ContainerImage extends software.amazon.jsii.JsiiObject {

    protected ContainerImage(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected ContainerImage(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    protected ContainerImage() {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this);
    }

    /**
     * Reference an image that's constructed directly from sources on disk.
     * <p>
     * If you already have a <code>DockerImageAsset</code> instance, you can use the
     * <code>ContainerImage.fromDockerImageAsset</code> method instead.
     * <p>
     * @param directory The directory containing the Dockerfile. This parameter is required.
     * @param props
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.AssetImage fromAsset(final @org.jetbrains.annotations.NotNull java.lang.String directory, final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ecs.AssetImageProps props) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ecs.ContainerImage.class, "fromAsset", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ecs.AssetImage.class), new Object[] { java.util.Objects.requireNonNull(directory, "directory is required"), props });
    }

    /**
     * Reference an image that's constructed directly from sources on disk.
     * <p>
     * If you already have a <code>DockerImageAsset</code> instance, you can use the
     * <code>ContainerImage.fromDockerImageAsset</code> method instead.
     * <p>
     * @param directory The directory containing the Dockerfile. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.AssetImage fromAsset(final @org.jetbrains.annotations.NotNull java.lang.String directory) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ecs.ContainerImage.class, "fromAsset", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ecs.AssetImage.class), new Object[] { java.util.Objects.requireNonNull(directory, "directory is required") });
    }

    /**
     * Use an existing `DockerImageAsset` for this container image.
     * <p>
     * @param asset The `DockerImageAsset` to use for this container definition. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.ContainerImage fromDockerImageAsset(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecr.assets.DockerImageAsset asset) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ecs.ContainerImage.class, "fromDockerImageAsset", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ecs.ContainerImage.class), new Object[] { java.util.Objects.requireNonNull(asset, "asset is required") });
    }

    /**
     * Reference an image in an ECR repository.
     * <p>
     * @param repository This parameter is required.
     * @param tag
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.EcrImage fromEcrRepository(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecr.IRepository repository, final @org.jetbrains.annotations.Nullable java.lang.String tag) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ecs.ContainerImage.class, "fromEcrRepository", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ecs.EcrImage.class), new Object[] { java.util.Objects.requireNonNull(repository, "repository is required"), tag });
    }

    /**
     * Reference an image in an ECR repository.
     * <p>
     * @param repository This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.EcrImage fromEcrRepository(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecr.IRepository repository) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ecs.ContainerImage.class, "fromEcrRepository", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ecs.EcrImage.class), new Object[] { java.util.Objects.requireNonNull(repository, "repository is required") });
    }

    /**
     * Reference an image on DockerHub or another online registry.
     * <p>
     * @param name This parameter is required.
     * @param props
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.RepositoryImage fromRegistry(final @org.jetbrains.annotations.NotNull java.lang.String name, final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ecs.RepositoryImageProps props) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ecs.ContainerImage.class, "fromRegistry", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ecs.RepositoryImage.class), new Object[] { java.util.Objects.requireNonNull(name, "name is required"), props });
    }

    /**
     * Reference an image on DockerHub or another online registry.
     * <p>
     * @param name This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.RepositoryImage fromRegistry(final @org.jetbrains.annotations.NotNull java.lang.String name) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ecs.ContainerImage.class, "fromRegistry", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ecs.RepositoryImage.class), new Object[] { java.util.Objects.requireNonNull(name, "name is required") });
    }

    /**
     * Called when the image is used by a ContainerDefinition.
     * <p>
     * @param scope This parameter is required.
     * @param containerDefinition This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public abstract @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.ContainerImageConfig bind(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.ContainerDefinition containerDefinition);

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    @software.amazon.jsii.Internal
    private static final class Jsii$Proxy extends software.amazon.awscdk.services.ecs.ContainerImage {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * Called when the image is used by a ContainerDefinition.
         * <p>
         * @param scope This parameter is required.
         * @param containerDefinition This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.ContainerImageConfig bind(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.ecs.ContainerDefinition containerDefinition) {
            return software.amazon.jsii.Kernel.call(this, "bind", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ecs.ContainerImageConfig.class), new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(containerDefinition, "containerDefinition is required") });
        }
    }
}
